[jboss-cvs] JBossAS SVN: r107954 - projects/cluster/ha-server-cache-spi/trunk/src/main/java/org/jboss/web/tomcat/service/session/distributedcache/spi.

jboss-cvs-commits at lists.jboss.org jboss-cvs-commits at lists.jboss.org
Thu Sep 2 13:19:45 EDT 2010


Author: pferraro
Date: 2010-09-02 13:19:45 -0400 (Thu, 02 Sep 2010)
New Revision: 107954

Modified:
   projects/cluster/ha-server-cache-spi/trunk/src/main/java/org/jboss/web/tomcat/service/session/distributedcache/spi/DistributedCacheManager.java
   projects/cluster/ha-server-cache-spi/trunk/src/main/java/org/jboss/web/tomcat/service/session/distributedcache/spi/LocalDistributableSessionManager.java
Log:
JBAS-7853 Migrate sessions that use jvmRoute to nodes where they are local cached

Modified: projects/cluster/ha-server-cache-spi/trunk/src/main/java/org/jboss/web/tomcat/service/session/distributedcache/spi/DistributedCacheManager.java
===================================================================
--- projects/cluster/ha-server-cache-spi/trunk/src/main/java/org/jboss/web/tomcat/service/session/distributedcache/spi/LocalDistributableSessionManager.java	2010-09-02 15:34:25 UTC (rev 107953)
+++ projects/cluster/ha-server-cache-spi/trunk/src/main/java/org/jboss/web/tomcat/service/session/distributedcache/spi/LocalDistributableSessionManager.java	2010-09-02 17:19:45 UTC (rev 107954)
@@ -102,5 +102,10 @@
     */
    boolean sessionChangedInDistributedCache(String realId, String dataOwner, int distributedVersion,
          long timestamp, DistributableSessionMetadata metadata);
-
+   
+   /**
+    * Returns the jvm route of this node.
+    * @return a jvm route
+    */
+   String getJvmRoute();
 }
\ No newline at end of file



More information about the jboss-cvs-commits mailing list
--- projects/cluster/ha-server-cache-spi/trunk/src/main/java/org/jboss/web/tomcat/service/session/distributedcache/spi/DistributedCacheManager.java	2010-09-02 15:34:25 UTC (rev 107953)
+++ projects/cluster/ha-server-cache-spi/trunk/src/main/java/org/jboss/web/tomcat/service/session/distributedcache/spi/DistributedCacheManager.java	2010-09-02 17:19:45 UTC (rev 107954)
@@ -159,8 +159,15 @@
    
    /**
     * Indicates whether a session with the specified identifier will cache locally.
     * @param realId a session identifier
     * @return true, if a session with the specified identifier will cache locally, false otherwise.
     */
-   boolean isLocal(String realId);
+   boolean isLocal(String sessionId);
+   
+   /**
+    * Returns the jvm route of a node on which the specified session id is cached.
+    * @param sessionId a session identifier
+    * @return the jvm route of a node
+    */
+   String locate(String sessionId);
 }
@@ -159,8 +159,15 @@
    /**
     * Indicates whether a session with the specified identifier will cache locally.
-    * @param realId a session identifier
+    * @param sessionId a session identifier
     * @return true, if a session with the specified identifier will cache locally, false otherwise.
     */

Modified: projects/cluster/ha-server-cache-spi/trunk/src/main/java/org/jboss/web/tomcat/service/session/distributedcache/spi/LocalDistributableSessionManager.java
===================================================================